// Copyright 1999-2017. Parallels IP Holdings GmbH. All Rights Reserved.

(function (ce, cssPrefix) {

    PleskExt.Docker.Sidebar = Class.create(Jsw.Component, {
        _initConfiguration: function ($super, config) {
            $super(config);

            this.container = this._getConfigParam('container', {});
        },

        _initComponentElement: function ($super) {
            $super();

            this._componentElement = this.panelsGroupView([{
                title: this.lmsg('resourcesSection'),
                content: this.resourcesView()
            }]);
        },

        panelsGroupView: function (panels) {
            return ce(".panels-group",
                panels.map(this.panelView.bind(this))
            );
        },

        panelView: function (panel) {
            return ce(".panel",
                ce(".panel-wrap",
                    ce(".panel-heading",
                        ce(".panel-heading-wrap",
                            ce("h4.panel-heading-name",
                                ce("span", panel.title)
                            )
                        )
                    ),
                    ce(".panel-content",
                        ce(".panel-content-wrap", panel.content)
                    )
                )
            );
        },

        resourcesView: function () {
            return [
                this.container.memory ? ce(".progress-box.resource-usage",
                    ce(".progress-label",
                        ce("span.resource-usage-name", this.lmsg('memory') + ":"), " ",
                        ce("b.resource-usage-value", this.lmsg('memoryUsage', {
                            "usage": this.container.memory.usage.escapeHTML(),
                            "limit": this.container.memory.limit.escapeHTML()
                        }))
                    ),
                    ce(".progress.progress-sm",
                        ce(".progress-bar" + (this.container.memory.usagePercent === 100 ? ".progress-bar-danger" : ""), {"style": "width: " + this.container.memory.usagePercent + "%;"})
                    )
                ) : "",
                this.container.cpu ? ce(".progress-box.resource-usage",
                    ce(".progress-label",
                        ce("span.resource-usage-name", this.lmsg('cpu') + ":")
                    ),
                    ce(".progress.progress-sm",
                        ce(".progress-bar", {"style": "width: " + this.container.cpu.usagePercent + "%;"})
                    )
                ) : "",
                ce("ul.data-list",
                    ce("li.data-list-item",
                        ce("span.data-list-name", this.lmsg('containerId') + ":"), " ",
                        ce("span.data-list-value", this.container.id.escapeHTML())
                    ),
                    this.container.mounts && this.container.mounts.length ? ce("li.data-list-item",
                        ce("p.data-list-title", this.lmsg('mounts') + ':'),
                        this.container.mounts.map(function (mount) {
                            return ce("p",
                                mount.source ? this.lmsg('mountOn', {
                                    "source": '<span class="data-list-name">' + mount.source.escapeHTML() + '</span>',
                                    "destination": '<span class="data-list-value">' + mount.destination.escapeHTML() + '</span>'
                                }) : this.lmsg('notMount', {
                                    "destination": '<span class="data-list-value">' + mount.destination.escapeHTML() + '</span>'
                                })
                            );
                        }.bind(this))
                    ) : '',
                    this.container.ports && Object.keys(this.container.ports).length ? ce("li.data-list-item",
                        ce("p.data-list-title", this.lmsg('ports') + ':'),
                        Object.keys(this.container.ports).map(function (port) {
                            var isSecure = port.match(/443$/),
                                isShow = !!this.container.ports[port],
                                protocol = isSecure ? 'https' : 'http',
                                host = this.container.host ? this.container.host.escapeHTML() : window.location.hostname,
                                privatePort = port.escapeHTML(),
                                publicPort = this.container.ports[port].escapeHTML(),
                                url = isShow ? protocol + '://' + host + ':' + publicPort : '',
                                linkElement = isShow ? ce('a.' + cssPrefix + 'icon-external', {
                                    href: url,
                                    target: '_blank'
                                }) : '';
                            return ce("p",
                                this.lmsg('portTo', {
                                    "source": '<span class="data-list-name">' + privatePort + '</span>',
                                    "destination": '<span class="data-list-value">' + publicPort + '</span>'
                                }),
                                linkElement
                            );
                        }.bind(this))
                    ) : ''
                )
            ];
        }
    });

})(Jsw.createElement, PleskExt.Docker.PleskExtPrefix);
